@@ -1,8 +1,5 @@
 package App::lcpan::Cmd::cpantesters_dist;
 
-our $DATE = '2018-09-12'; # DATE
-our $VERSION = '0.002'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -12,6 +9,11 @@ use Perinci::Object;
 
 require App::lcpan;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-27'; # DATE
+our $DIST = 'App-lcpan-CmdBundle-cpantesters'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 our %SPEC;
 
 $SPEC{handle_cmd} = {
@@ -39,7 +41,7 @@ sub handle_cmd {
     my $envres = envresmulti();
     for my $dist (@{ $args{dists} }) {
         my ($file_id, $cpanid, $version) = $dbh->selectrow_array(
-            "SELECT file_id, cpanid, version FROM dist WHERE name=? AND is_latest", {}, $dist);
+            "SELECT id, cpanid, dist_version FROM file WHERE dist_name=? AND is_latest_dist", {}, $dist);
         $file_id or do {
             $envres->add_result(404, "No such dist '$dist'");
             next;
@@ -72,7 +74,7 @@ App::lcpan::Cmd::cpantesters_dist - Open distribution page on CPAN Testers matri
 
 =head1 VERSION
 
-This document describes version 0.002 of App::lcpan::Cmd::cpantesters_dist (from Perl distribution App-lcpan-CmdBundle-cpantesters), released on 2018-09-12.
+This document describes version 0.003 of App::lcpan::Cmd::cpantesters_dist (from Perl distribution App-lcpan-CmdBundle-cpantesters), released on 2022-03-27.
 
 =head1 DESCRIPTION
 
@@ -85,7 +87,7 @@ This module handles the L<lcpan> subcommand C<cpantesters-dist>.
 
 Usage:
 
- handle_cmd(%args) -> [status, msg, result, meta]
+ handle_cmd(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Open distribution page on CPAN Testers matrix.
 
@@ -101,12 +103,14 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<dirname>
 
-Location of your local CPAN mirror, e.g. /path/to/cpan.
+Location of your local CPAN mirror, e.g. E<sol>pathE<sol>toE<sol>cpan.
 
 Defaults to C<~/cpan>.
 
 =item * B<dists>* => I<array[perl::distname]>
 
+Distribution names (e.g. Foo-Bar).
+
 =item * B<index_name> => I<filename> (default: "index.db")
 
 Filename of index.
@@ -116,16 +120,24 @@ be located in the top-level of C<cpan>. If C<index_name> contains a path, e.g.
 C<./index.db> or C</home/ujang/lcpan.db> then the index will be located solely
 using the C<index_name>.
 
+=item * B<use_bootstrap> => I<bool> (default: 1)
+
+Whether to use bootstrap database from App-lcpan-Bootstrap.
+
+If you are indexing your private CPAN-like repository, you want to turn this
+off.
+
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -137,6 +149,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-
 
 Source repository is at L<https://github.com/perlancar/perl-App-lcpan-CmdBundle-cpantesters>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2018 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-cpantesters>
@@ -145,15 +185,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2018 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
