@@ -1,7 +1,11 @@
 package App::lcpan::CmdBundle::cpantesters;
 
-our $DATE = '2018-09-12'; # DATE
-our $VERSION = '0.002'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-03-27'; # DATE
+our $DIST = 'App-lcpan-CmdBundle-cpantesters'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: More lcpan subcommands related to CPAN Testers
@@ -18,7 +22,7 @@ App::lcpan::CmdBundle::cpantesters - More lcpan subcommands related to CPAN Test
 
 =head1 VERSION
 
-This document describes version 0.002 of App::lcpan::CmdBundle::cpantesters (from Perl distribution App-lcpan-CmdBundle-cpantesters), released on 2018-09-12.
+This document describes version 0.003 of App::lcpan::CmdBundle::cpantesters (from Perl distribution App-lcpan-CmdBundle-cpantesters), released on 2022-03-27.
 
 =head1 SYNOPSIS
 
@@ -28,10 +32,10 @@ This bundle provides the following lcpan subcommands:
 
 =over
 
-=item * L<lcpan cpantesters-dist|App::lcpan::Cmd::cpantesters_dist>
-
 =item * L<lcpan cpantesters-author|App::lcpan::Cmd::cpantesters_author>
 
+=item * L<lcpan cpantesters-dist|App::lcpan::Cmd::cpantesters_dist>
+
 =back
 
 =head1 HOMEPAGE
@@ -42,14 +46,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-
 
 Source repository is at L<https://github.com/perlancar/perl-App-lcpan-CmdBundle-cpantesters>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-cpantesters>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<lcpan>
@@ -60,11 +56,36 @@ L<https://www.cpantesters.org>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-cpantesters>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
